package com.fs.store.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.store.mapper.FsStoreAfterSalesStatusMapper;
import com.fs.store.domain.FsStoreAfterSalesStatus;
import com.fs.store.service.IFsStoreAfterSalesStatusService;

/**
 * 售后订单操作Service业务层处理
 * 
 * @author fs
 * @date 2022-03-15
 */
@Service
public class FsStoreAfterSalesStatusServiceImpl implements IFsStoreAfterSalesStatusService 
{
    @Autowired
    private FsStoreAfterSalesStatusMapper fsStoreAfterSalesStatusMapper;

    /**
     * 查询售后订单操作
     * 
     * @param id 售后订单操作ID
     * @return 售后订单操作
     */
    @Override
    public FsStoreAfterSalesStatus selectFsStoreAfterSalesStatusById(Long id)
    {
        return fsStoreAfterSalesStatusMapper.selectFsStoreAfterSalesStatusById(id);
    }

    /**
     * 查询售后订单操作列表
     * 
     * @param fsStoreAfterSalesStatus 售后订单操作
     * @return 售后订单操作
     */
    @Override
    public List<FsStoreAfterSalesStatus> selectFsStoreAfterSalesStatusList(FsStoreAfterSalesStatus fsStoreAfterSalesStatus)
    {
        return fsStoreAfterSalesStatusMapper.selectFsStoreAfterSalesStatusList(fsStoreAfterSalesStatus);
    }

    /**
     * 新增售后订单操作
     * 
     * @param fsStoreAfterSalesStatus 售后订单操作
     * @return 结果
     */
    @Override
    public int insertFsStoreAfterSalesStatus(FsStoreAfterSalesStatus fsStoreAfterSalesStatus)
    {
        return fsStoreAfterSalesStatusMapper.insertFsStoreAfterSalesStatus(fsStoreAfterSalesStatus);
    }

    /**
     * 修改售后订单操作
     * 
     * @param fsStoreAfterSalesStatus 售后订单操作
     * @return 结果
     */
    @Override
    public int updateFsStoreAfterSalesStatus(FsStoreAfterSalesStatus fsStoreAfterSalesStatus)
    {
        return fsStoreAfterSalesStatusMapper.updateFsStoreAfterSalesStatus(fsStoreAfterSalesStatus);
    }

    /**
     * 批量删除售后订单操作
     * 
     * @param ids 需要删除的售后订单操作ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreAfterSalesStatusByIds(Long[] ids)
    {
        return fsStoreAfterSalesStatusMapper.deleteFsStoreAfterSalesStatusByIds(ids);
    }

    /**
     * 删除售后订单操作信息
     * 
     * @param id 售后订单操作ID
     * @return 结果
     */
    @Override
    public int deleteFsStoreAfterSalesStatusById(Long id)
    {
        return fsStoreAfterSalesStatusMapper.deleteFsStoreAfterSalesStatusById(id);
    }
}
